==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebAvatarDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebAvatarDescription } from "./WebAvatarDescription";
/**
 * @hidden
 */
var WebAvatarDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebAvatarDescriptionMetadata, _super);
    function WebAvatarDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebAvatarDescriptionMetadata.b = function (a) {
        if (WebAvatarDescriptionMetadata.a == null) {
            WebAvatarDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebAvatarDescriptionMetadata.c(WebAvatarDescriptionMetadata.a);
        }
        if (a.j(WebAvatarDescriptionMetadata.a)) {
            return;
        }
        a.y(WebAvatarDescriptionMetadata.a);
    };
    WebAvatarDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Avatar");
        a.item("__tagNameWC", "String:igc-avatar");
        a.item("Src", "String");
        a.item("Alt", "String");
        a.item("Initials", "String");
        a.item("Shape", "ExportedType:string:AvatarShape");
        a.item("Shape@names", "Circle;Rounded;Square");
        a.item("Size", "ExportedType:string:SizableComponentSize");
        a.item("Size@names", "Large;Small;Medium");
    };
    WebAvatarDescriptionMetadata.d = function (a) {
        WebAvatarDescriptionMetadata.b(a);
        a.aa("WebAvatar", function () { return new WebAvatarDescription(); });
        a.z("WebAvatar", WebAvatarDescriptionMetadata.a);
    };
    WebAvatarDescriptionMetadata.$t = markType(WebAvatarDescriptionMetadata, 'WebAvatarDescriptionMetadata');
    WebAvatarDescriptionMetadata.a = null;
    return WebAvatarDescriptionMetadata;
}(Base));
export { WebAvatarDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebAvatarDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebAvatarDescription } from "./WebAvatarDescription";
/**
 * @hidden
 */
var WebAvatarDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebAvatarDescriptionMetadata, _super);
    function WebAvatarDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebAvatarDescriptionMetadata.b = function (a) {
        if (WebAvatarDescriptionMetadata.a == null) {
            WebAvatarDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebAvatarDescriptionMetadata.c(WebAvatarDescriptionMetadata.a);
        }
        if (a.k(WebAvatarDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebAvatarDescriptionMetadata.a);
    };
    WebAvatarDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Avatar");
        a.item("__tagNameWC", "String:igc-avatar");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Src", "String");
        a.item("Alt", "String");
        a.item("Initials", "String");
        a.item("Shape", "ExportedType:string:AvatarShape");
        a.item("Shape@stringUnion", "WebComponents;React");
        a.item("Shape@names", "Circle;Rounded;Square");
        a.item("Size", "ExportedType:string:SizableComponentSize");
        a.item("Size@names", "Large;Small;Medium");
    };
    WebAvatarDescriptionMetadata.d = function (a) {
        WebAvatarDescriptionMetadata.b(a);
        a.ac("WebAvatar", function () { return new WebAvatarDescription(); });
        a.ab("WebAvatar", WebAvatarDescriptionMetadata.a);
    };
    WebAvatarDescriptionMetadata.$t = markType(WebAvatarDescriptionMetadata, 'WebAvatarDescriptionMetadata');
    WebAvatarDescriptionMetadata.a = null;
    return WebAvatarDescriptionMetadata;
}(Base));
export { WebAvatarDescriptionMetadata };
